@@ -27,6 +27,7 @@
 
 #include "clutter-debug.h"
 #include "clutter-device-manager-private.h"
+#include "clutter-event-private.h"
 #include "clutter-private.h"
 #include "clutter-stage-private.h"
 
@@ -94,15 +95,44 @@ clutter_input_device_xi2_init (ClutterInputDeviceXI2 *self)
 {
 }
 
-guint
-_clutter_input_device_xi2_translate_state (XIModifierState *modifiers_state,
+static ClutterModifierType
+get_modifier_for_button (int i)
+{
+  switch (i)
+    {
+    case 1:
+      return CLUTTER_BUTTON1_MASK;
+    case 2:
+      return CLUTTER_BUTTON2_MASK;
+    case 3:
+      return CLUTTER_BUTTON3_MASK;
+    case 4:
+      return CLUTTER_BUTTON4_MASK;
+    case 5:
+      return CLUTTER_BUTTON5_MASK;
+    default:
+      return 0;
+    }
+}
+
+void
+_clutter_input_device_xi2_translate_state (ClutterEvent    *event,
+					   XIModifierState *modifiers_state,
                                            XIButtonState   *buttons_state,
                                            XIGroupState    *group_state)
 {
-  guint retval = 0;
+  guint button = 0;
+  guint base = 0;
+  guint latched = 0;
+  guint locked = 0;
+  guint effective;
 
   if (modifiers_state)
-    retval = (guint) modifiers_state->effective;
+    {
+      base = (guint) modifiers_state->base;
+      latched = (guint) modifiers_state->latched;
+      locked = (guint) modifiers_state->locked;
+    }
 
   if (buttons_state)
     {
@@ -115,36 +145,30 @@ _clutter_input_device_xi2_translate_state (XIModifierState *modifiers_state,
           if (!XIMaskIsSet (buttons_state->mask, i))
             continue;
 
-          switch (i)
-            {
-            case 1:
-              retval |= CLUTTER_BUTTON1_MASK;
-              break;
-
-            case 2:
-              retval |= CLUTTER_BUTTON2_MASK;
-              break;
-
-            case 3:
-              retval |= CLUTTER_BUTTON3_MASK;
-              break;
-
-            case 4:
-              retval |= CLUTTER_BUTTON4_MASK;
-              break;
-
-            case 5:
-              retval |= CLUTTER_BUTTON5_MASK;
-              break;
-
-            default:
-              break;
-            }
+          button |= get_modifier_for_button (i);
         }
     }
 
-  if (group_state)
-    retval |= (group_state->effective) << 13;
+  /* The XIButtonState sent in the event specifies the
+   * state of the buttons before the event. In order to
+   * get the current state of the buttons, we need to
+   * filter out the current button.
+   */
+  switch (event->type)
+    {
+    case CLUTTER_BUTTON_PRESS:
+      button |=  (get_modifier_for_button (event->button.button));
+      break;
+    case CLUTTER_BUTTON_RELEASE:
+      button &= ~(get_modifier_for_button (event->button.button));
+      break;
+    default:
+      break;
+    }
 
-  return retval;
+  effective = button | base | latched | locked;
+  if (group_state)
+    effective |= (group_state->effective) << 13;
+
+  _clutter_event_set_state_full (event, button, base, latched, locked, effective);
 }
